# archive-file-urls

`archive-file-urls` scans a file for URLs
and submits them to the [Internet Archive Wayback Machine](https://web.archive.org/)
in order for them to be archived.
The program optionally supports exporting the resulting Internet Archive URLs.

This is useful in all sorts of situations.
Take personal blog articles in any format (Markdown, HTML, ...) for example: You can use this program to save the linked web pages.

The same goes for when you create a LaTex document and want to save the websites cited inside a [BibTeX](http://www.bibtex.org/) file.

And of course, there are many more ways to utilize this program.

## Installation

`pip install archive-file-urls`

## Usage

`archive-file-urls --help`
